/***********************************************************
 * $Id: RequestHelper.java 617 2012-07-15 16:10:09Z util $
 * 
 * HTTP Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 15.07.2012
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.http;

import java.util.Enumeration;

import javax.servlet.http.HttpServletRequest;

/**
 * Static helper function for extracting special information from
 * requests.
 */
public abstract class RequestHelper {

	/**
	 * <p>Get the remote IP address of the client taking the
	 * <code>X-Forwarded-for</code> header into account.</p>
	 * 
	 * <p>If no <code>X-Forwarded-for</code> header is present,
	 * the value of {@link HttpServletRequest#getRemoteAddr()}
	 * is returned.</p>
	 * 
	 * <p>If a <code>X-Forwarded-for</code> header is present,
	 * the leftmost value in the comma-separated list of
	 * <code>X-Forwarded-for</code>-addresses is returned.
	 * The rationale for returning the leftmost address is, that
	 * this is the original address of the client.</p>
	 * 
	 * @param request A HTTP servlet request.
	 * @return The remote IP address of the client.
	 */
	public static String getRealRemoteIP(final HttpServletRequest request) {
		@SuppressWarnings("unchecked")
		final Enumeration<String> headers = request
				.getHeaders("X-Forwarded-for");
		if (headers != null) {
			while (headers.hasMoreElements()) {
				final String[] ips = headers.nextElement().split(",");
				for (int i = 0; i < ips.length; i++) {
					final String realRemoteAddr = ips[i].trim();
					if (!"unknown".equals(realRemoteAddr)
							&& !realRemoteAddr.isEmpty()) {
						return realRemoteAddr;
					}
				}
			}
		}
		return request.getRemoteAddr();
	}

}
