/***********************************************************
 * $Id: ResponseHelper.java 514 2011-08-19 12:44:14Z util $
 * 
 * HTTP Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 19.08.2011
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.http;

import javax.servlet.http.HttpServletResponse;

/**
 * Static helper functions for frequently needed additions to HTTP responses.
 */
public abstract class ResponseHelper {

	/**
	 * Set the following HTTP headers fields in order to mark the servlet's
	 * output as purely dynamic content not to be cached by any browser.
	 * 
	 * <pre>
	 * Cache-Control: no-cache
	 * Pragma: no-cache
	 * Expires: 0
	 * </pre>
	 * 
	 * @param resp The servlet response to be marked as dynamic content.
	 */
	public static final void setNoCacheHeaders(HttpServletResponse resp) {
		resp.setHeader("Cache-Control","no-cache");
		resp.setHeader("Pragma","no-cache");
		resp.setHeader("Expires","0");
	}
}
