/***********************************************************
 * $Id: CheckLoginService.java 392 2011-05-19 20:38:05Z gwt $
 * 
 * HTTP/Servlet Utilities of clazzes.org
 * http://www.clazzes.org
 *
 * Created: 18.05.2011
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.http.sec;

/**
 * A base interface for remote services to check for logged in persons. 
 */
public interface CheckLoginService {

	/**
	 * @return The logged in user.
	 * @throws LoginRequiredException if no user is logged in.
	 */
	public String checkLogin() throws LoginRequiredException;

	/**
	 * @return The URL of the login servlet inside the login iframe.
	 */
	public String getLoginUrl();
	
	/**
	 * @return The locale used to log in the user. The format of the
	 *         returned locale is in XML format (en, en-GB, de, de-AT,...)
	 *         with hyphens to separate the language and the country,
	 *         if the latter is known.
	 */
	public String getLocale();
	
	/**
	 * Check the permission of the logged in user on the given context
	 * URL.
	 * @param contextUrl The context Url.
	 * @return Whether the user is allowed to operate on the given
	 *         context URL.
	 */
	public boolean checkPermission(String contextUrl);
	
	/**
	 * Remove all login properties from the HTTP session and log the user out.
	 */
	public void logout();
}
